<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>SelectByHandle</name>
    <message>
        <source>Object selected: </source>
        <translation type="vanished">Izbran objekt: </translation>
    </message>
    <message>
        <source>Object is not an entity: </source>
        <translation type="vanished">Objekt ni entiteta: </translation>
    </message>
    <message>
        <location filename="../SelectByHandleInit.js" line="+2"/>
        <source>By Handle</source>
        <translation>Po identifikatorju</translation>
    </message>
    <message>
        <location filename="../SelectByHandle.js" line="+58"/>
        <source>Object selected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Object is not an entity:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectByHandleDialog</name>
    <message>
        <location filename="../SelectByHandleDialog.ui" line="+17"/>
        <source>Selection by Handle</source>
        <translation>Izbor po identifikatorju</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Handle (hex):</source>
        <translation>Identifikator (hex):</translation>
    </message>
</context>
</TS>
